
NO_SVS_ID_ERROR = "Cannot find year {year} in this version "\
                "of the package. This package can get moons for years {year_range_0} -"\
                " {year_range_1}. Please try a different year or check for an update "\
                "for this package."

UPDATED_PACKAGE_EXISTS_WITH_YEAR_ID = 	"Warning: There's a newer version of this `moon` package "\
										"that includes the requested year {year}. Your version "\
										"of this package has made an extra request to get the "\
										"ID for year {year} by requesting it from "\
										"the GitHub repo with the updated version of the "\
										"moon package. If you update this package, "\
										"it won't have to make this extra request next time."

HOUR_ERROR = "Hour is not between 0 and 23."
